@@ -5,7 +5,7 @@ from django.core.validators import RegexValidator, URLValidator
 from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext_lazy as _
 
-from urls import get_named_url_from_quoted_url, is_quoted_url
+from .urls import get_named_url_from_quoted_url, is_quoted_url
 
 
 class FiberURLValidator(RegexValidator):
